"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer = require("inquirer");
const command_1 = require("@oclif/command");
const graphql_1 = require("@octokit/graphql");
const tempFile_1 = require("../utils/tempFile");
const Configstore = require("configstore");
const fs = require("fs");
const util = require("util");
const config = new Configstore("hashnode-cli");
const readFile = util.promisify(fs.readFile);
// This overwrites the default list prompt. Add types to the search list package in the future
inquirer.registerPrompt("list", require("inquirer-search-list"));
const graphqlWithAuth = graphql_1.graphql.defaults({
    baseUrl: "https://api.hashnode.com/graphql",
    headers: {
        authorization: config.get("token"),
    },
});
class CreatePost extends command_1.Command {
    async run() {
        const { flags } = this.parse(CreatePost);
        if (!config.get("token")) {
            console.log("You are not authenticated. Please run 'hashnode-cli login'");
            return;
        }
        try {
            let title = flags.title;
            if (!title) {
                title = await inquirer.prompt({
                    name: "title",
                    message: "Post title?",
                    validate: function (title) {
                        if (title.trim().length < 6) {
                            return "Title too short.";
                        }
                        return true;
                    },
                });
            }
            const temp = await tempFile_1.default({
                name: title,
            });
            let tagCategories = config.get("tag-categories");
            if (!tagCategories) {
                const tagCategoriesRes = await graphqlWithAuth(`
          query {
            tagCategories{
              _id
              name
            }
          }
          `);
                tagCategories = tagCategoriesRes.tagCategories;
                config.set("tag-categories", tagCategories);
            }
            require("child_process").spawnSync("nano", [temp], {
                stdio: "inherit",
                detached: true,
            });
            const selectedTags = [];
            tagCategories.push({ _id: "undefined", name: "none" });
            const getTags = async () => {
                for (let i = 1; i <= 5; i++) {
                    const { tag } = await inquirer.prompt({
                        name: `tag`,
                        message: `input tag ${i} (enter 'none' to skip)?`,
                        type: "list",
                        choices: tagCategories,
                    });
                    if (tag !== "none") {
                        const tagCategoryIndex = tagCategories.findIndex((t) => t.name === tag);
                        tagCategories.splice(tagCategoryIndex, 1);
                        selectedTags.push(tagCategories[tagCategoryIndex]);
                    }
                }
            };
            while (selectedTags.length === 0) {
                await getTags();
            }
            const contentMarkdown = await readFile(temp, "utf8");
            const { createStory } = await graphqlWithAuth(`
        mutation storyCreation($title: String!, $contentMarkdown: String!, $tags: [TagsInput]!) {
          createStory(
            input: {
              title: $title
              contentMarkdown: $contentMarkdown
              tags: $tags
            }
          ) {
            success
            message
            post{
              slug
              cuid
            }
          }
        }
        `, {
                title,
                contentMarkdown,
                tags: selectedTags,
            });
            console.log(`${createStory.message}. \nView your post here. https://hashnode.com/post/${createStory.post.slug}-${createStory.post.cuid}`);
        }
        catch (error) {
            console.error(error.message);
        }
    }
}
exports.default = CreatePost;
CreatePost.description = "Creates a post on your hashnode blog from a markdown file.";
CreatePost.flags = {
    help: command_1.flags.help({ char: "h" }),
    title: command_1.flags.string({ char: "t", description: "post title" }),
};
