"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const Configstore = require("configstore");
const open = require("open");
const inquirer = require("inquirer");
const config = new Configstore("hashnode-cli");
class Login extends command_1.Command {
    async run() {
        const { flags } = this.parse(Login);
        if (flags.token) {
            config.set("token", flags.token);
            console.log("Token securely saved.");
            return;
        }
        this.log("Opening the developer settings.");
        await open("https://hashnode.com/settings/developer");
        inquirer
            .prompt([{ name: "token", message: "Paste Hashnode developer token?" }])
            .then(({ token }) => {
            config.set("token", token);
            console.log("Token securely saved.");
        })
            .catch((error) => {
            if (error.isTtyError) {
                console.log("Prompt couldn't be rendered in the current environment");
            }
            else {
                console.log("Sometime went wrong, please try again");
            }
        });
    }
}
exports.default = Login;
Login.description = "authenticate the CLI by pasting your developer token";
Login.flags = {
    help: command_1.flags.help({ char: "h" }),
    token: command_1.flags.string({
        char: "t",
        description: "Hashnode token from the developer settings",
    }),
};
